@@ -10,7 +10,7 @@ Released under the GNU GPL version 3 or later
 import sys, os, struct, math, time, socket
 import fnmatch, errno, threading
 import serial, Queue, select
-
+import traceback
 import select
 
 # allow running without installing
@@ -471,6 +471,8 @@ def process_stdin(line):
         fn(args[1:])
     except Exception as e:
         print("ERROR in command: %s" % str(e))
+        if mpstate.settings.moddebug > 1:
+            traceback.print_exc()
 
 
 def vcell_to_battery_percent(vcell):
@@ -774,7 +776,6 @@ def master_callback(m, master):
                 if mpstate.settings.moddebug == 1:
                     print(msg)
                 elif mpstate.settings.moddebug > 1:
-                    import traceback
                     exc_type, exc_value, exc_traceback = sys.exc_info()
                     traceback.print_exception(exc_type, exc_value, exc_traceback,
                                               limit=2, file=sys.stdout)
@@ -967,7 +968,6 @@ def periodic_tasks():
                 if mpstate.settings.moddebug == 1:
                     print(msg)
                 elif mpstate.settings.moddebug > 1:
-                    import traceback
                     exc_type, exc_value, exc_traceback = sys.exc_info()
                     traceback.print_exception(exc_type, exc_value, exc_traceback,
                                               limit=2, file=sys.stdout)
